@@ -33,7 +33,7 @@ else
     sed -i 's/\[delorean\]/\[delorean-current\]/' $REPO_PREFIX/delorean-current.repo
     /bin/bash -c "cat <<-EOF>>$REPO_PREFIX/delorean-current.repo
 
-includepkgs=diskimage-builder,instack,instack-undercloud,os-apply-config,os-collect-config,os-net-config,os-refresh-config,python-tripleoclient,openstack-tripleo-common,openstack-tripleo-heat-templates,openstack-tripleo-image-elements,openstack-tripleo,openstack-tripleo-puppet-elements,openstack-puppet-modules,openstack-tripleo-ui,puppet-*
+includepkgs=diskimage-builder,instack,instack-undercloud,os-apply-config,os-collect-config,os-net-config,os-refresh-config,python-tripleoclient,openstack-tripleo-common,openstack-tripleo-heat-templates,openstack-tripleo-image-elements,openstack-tripleo,openstack-tripleo-puppet-elements,openstack-tripleo-ui,puppet-*
 EOF"
     cat $REPO_PREFIX/delorean-current.repo
 
@@ -47,7 +47,7 @@ yum install -y \
         file \
         initscripts \
         jq \
-        openstack-puppet-modules \
+        puppet-tripleo \
         openstack-tripleo-image-elements \
         openstack-tripleo-puppet-elements \
         openvswitch \
