@@ -19,7 +19,11 @@ import json
 import logging
 import multiprocessing
 import netifaces
+import os
+import requests
 import six
+from six.moves import urllib
+import subprocess
 import time
 
 import docker
@@ -34,15 +38,22 @@ from tripleo_common.image.exception import ImageUploaderException
 LOG = logging.getLogger(__name__)
 
 
+SECURE_REGISTRIES = (
+    'trunk.registry.rdoproject.org',
+    'docker.io',
+)
+
+
 class ImageUploadManager(BaseImageManager):
     """Manage the uploading of image files
 
        Manage the uploading of images from a config file specified in YAML
        syntax. Multiple config files can be specified. They will be merged.
        """
-    logger = logging.getLogger(__name__ + '.ImageUploadManager')
 
-    def __init__(self, config_files, verbose=False, debug=False):
+    def __init__(self, config_files=None, verbose=False, debug=False):
+        if config_files is None:
+            config_files = []
         super(ImageUploadManager, self).__init__(config_files)
         self.uploaders = {}
 
@@ -123,15 +134,23 @@ class ImageUploader(object):
         """Remove unused images or temporary files from upload"""
         pass
 
+    @abc.abstractmethod
+    def is_insecure_registry(self, registry_host):
+        """Detect whether a registry host is not configured with TLS"""
+        pass
+
 
 class DockerImageUploader(ImageUploader):
     """Upload images using docker push"""
 
     def __init__(self):
         self.upload_tasks = []
+        self.secure_registries = set()
+        self.insecure_registries = set()
 
     @staticmethod
-    def upload_image(image_name, pull_source, push_destination):
+    def upload_image(image_name, pull_source, push_destination,
+                     insecure_registries):
         LOG.info('imagename: %s' % image_name)
         dockerc = Client(base_url='unix://var/run/docker.sock', version='auto')
         if ':' in image_name:
@@ -145,13 +164,17 @@ class DockerImageUploader(ImageUploader):
         else:
             repo = image
 
-        DockerImageUploader._pull_retry(dockerc, repo, tag=tag)
-
         full_image = repo + ':' + tag
-
         new_repo = push_destination + '/' + repo.partition('/')[2]
         full_new_repo = new_repo + ':' + tag
 
+        if DockerImageUploader._images_match(full_image, full_new_repo,
+                                             insecure_registries):
+            LOG.info('Skipping upload for image %s' % image_name)
+            return []
+
+        DockerImageUploader._pull_retry(dockerc, repo, tag=tag)
+
         response = dockerc.tag(image=full_image, repository=new_repo,
                                tag=tag, force=True)
         LOG.debug(response)
@@ -160,7 +183,7 @@ class DockerImageUploader(ImageUploader):
                     tag=tag, stream=True)]
         LOG.debug(response)
 
-        LOG.info('Completed upload for docker image %s' % image_name)
+        LOG.info('Completed upload for image %s' % image_name)
         return full_image, full_new_repo
 
     @staticmethod
@@ -188,20 +211,60 @@ class DockerImageUploader(ImageUploader):
                 time.sleep(3)
                 LOG.warning('retrying pulling image: %s' % image)
 
-    def discover_image_tag(self, image, tag_from_label=None):
-        dockerc = Client(base_url='unix://var/run/docker.sock', version='auto')
+    @staticmethod
+    def _images_match(image1, image2, insecure_registries):
+        try:
+            image1_digest = DockerImageUploader._image_digest(
+                image1, insecure_registries)
+        except Exception:
+            return False
+        try:
+            image2_digest = DockerImageUploader._image_digest(
+                image2, insecure_registries)
+        except Exception:
+            return False
 
-        image_name, colon, tag = image.rpartition(':')
-        if not image_name:
-            image_name = tag
-            tag = None
-        if not tag:
-            tag = 'latest'
-        image = '%s:%s' % (image_name, tag)
+        # missing digest, no way to know if they match
+        if not image1_digest or not image2_digest:
+            return False
+        return image1_digest == image2_digest
 
-        DockerImageUploader._pull_retry(dockerc, image)
-        i = dockerc.inspect_image(image)
-        labels = i['Config']['Labels']
+    @staticmethod
+    def _image_digest(image, insecure_registries):
+        image_url = DockerImageUploader._image_to_url(image)
+        insecure = image_url.netloc in insecure_registries
+        i = DockerImageUploader._inspect(image_url.geturl(), insecure)
+        return i.get('Digest')
+
+    @staticmethod
+    def _inspect(image, insecure=False):
+
+        cmd = ['skopeo', 'inspect']
+
+        if insecure:
+            cmd.append('--tls-verify=false')
+        cmd.append(image)
+
+        LOG.info('Running %s' % ' '.join(cmd))
+        env = os.environ.copy()
+        process = subprocess.Popen(cmd, env=env, stdout=subprocess.PIPE,
+                                   stderr=subprocess.PIPE)
+
+        out, err = process.communicate()
+        if process.returncode != 0:
+            raise ImageUploaderException('Error inspecting image: %s\n%s' %
+                                         (image, err))
+        return json.loads(out)
+
+    @staticmethod
+    def _image_to_url(image):
+        if '://' not in image:
+            image = 'docker://' + image
+        return urllib.parse.urlparse(image)
+
+    @staticmethod
+    def _discover_tag_from_inspect(i, image, tag_from_label=None):
+        labels = i.get('Labels', {})
 
         label_keys = ', '.join(labels.keys())
 
@@ -217,12 +280,40 @@ class DockerImageUploader(ImageUploader):
                 (image, tag_from_label, label_keys)
             )
 
-        # confirm the tag exists by pulling it, which should be fast
-        # because that image has just been pulled
-        versioned_image = '%s:%s' % (image_name, tag_label)
-        DockerImageUploader._pull_retry(dockerc, versioned_image)
+        # confirm the tag exists by checking for an entry in RepoTags
+        repo_tags = i.get('RepoTags', [])
+        if tag_label not in repo_tags:
+            raise ImageUploaderException(
+                'Image %s has no tag %s.\nAvailable tags: %s' %
+                (image, tag_label, ', '.join(repo_tags))
+            )
         return tag_label
 
+    def discover_image_tags(self, images, tag_from_label=None):
+        image_urls = [self._image_to_url(i) for i in images]
+
+        # prime self.insecure_registries by testing every image
+        for url in image_urls:
+            self.is_insecure_registry(url.netloc)
+
+        discover_args = []
+        for image in images:
+            discover_args.append((image, tag_from_label,
+                                  self.insecure_registries))
+        p = multiprocessing.Pool(16)
+
+        versioned_images = {}
+        for image, versioned_image in p.map(discover_tag_from_inspect,
+                                            discover_args):
+            versioned_images[image] = versioned_image
+        return versioned_images
+
+    def discover_image_tag(self, image, tag_from_label=None):
+        image_url = self._image_to_url(image)
+        insecure = self.is_insecure_registry(image_url.netloc)
+        i = self._inspect(image_url.geturl(), insecure)
+        return self._discover_tag_from_inspect(i, image, tag_from_label)
+
     def cleanup(self, local_images):
         dockerc = Client(base_url='unix://var/run/docker.sock', version='auto')
         for image in sorted(local_images):
@@ -238,7 +329,14 @@ class DockerImageUploader(ImageUploader):
                     LOG.warning(e)
 
     def add_upload_task(self, image_name, pull_source, push_destination):
-        self.upload_tasks.append((image_name, pull_source, push_destination))
+        # prime self.insecure_registries
+        if pull_source:
+            self.is_insecure_registry(self._image_to_url(pull_source).netloc)
+        else:
+            self.is_insecure_registry(self._image_to_url(image_name).netloc)
+        self.is_insecure_registry(self._image_to_url(push_destination).netloc)
+        self.upload_tasks.append((image_name, pull_source, push_destination,
+                                  self.insecure_registries))
 
     def run_tasks(self):
         if not self.upload_tasks:
@@ -261,6 +359,33 @@ class DockerImageUploader(ImageUploader):
         # repeatedly
         self.cleanup(local_images)
 
+    def is_insecure_registry(self, registry_host):
+        if registry_host in self.secure_registries:
+            return False
+        if registry_host in self.insecure_registries:
+            return True
+        try:
+            requests.get('https://%s/' % registry_host)
+        except requests.exceptions.SSLError:
+            self.insecure_registries.add(registry_host)
+            return True
+        except Exception:
+            # for any other error assume it is a secure registry, because:
+            # - it is secure registry
+            # - the host is not accessible
+            pass
+        self.secure_registries.add(registry_host)
+        return False
+
 
 def docker_upload(args):
     return DockerImageUploader.upload_image(*args)
+
+
+def discover_tag_from_inspect(args):
+    image, tag_from_label, insecure_registries = args
+    image_url = DockerImageUploader._image_to_url(image)
+    insecure = image_url.netloc in insecure_registries
+    i = DockerImageUploader._inspect(image_url.geturl(), insecure)
+    return image, DockerImageUploader._discover_tag_from_inspect(
+        i, image, tag_from_label)
